@@ -54,8 +54,7 @@ kde_version_sfx    = None
 kde_version_extra  = None
 kde_max_version    = 0x030503
 
-sip_min_v3_version = 0x040400
-sip_min_v4_version = 0x040400
+sip_min_v4_version = 0x040501
 qt_min_version     = 0x030200
 pyqt_min_version   = 0x031000
 
@@ -176,12 +175,8 @@ def init_and_check_sanity ():
     if sipcfg.sip_version_str[:8] != "snapshot":
         minv = None
 
-        if sipcfg.sip_version >= 0x040000:
-            if sipcfg.sip_version < sip_min_v4_version:
-                minv = sip_min_v4_version
-        else:
-            if sipcfg.sip_version < sip_min_v3_version:
-                minv = sip_min_v3_version
+        if sipcfg.sip_version < sip_min_v4_version:
+            minv = sip_min_v4_version
 
         if minv:
             sipcfg.error("This version of PyKDE requires SIP v%s or later" % sipcfg.version_to_string(minv))
@@ -732,7 +727,6 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
         makefile.extra_libs.append ("kabc_file")
     if extra_lib == "kparts" and kde_version >= 0x030500:
         makefile.extra_lib_dirs.append (os.path.join (opt_kdelibdir, "kde3"))
-        makefile.extra_libs.append ("konsolepart")
 
     if extra_lib == "kdeprint":
         makefile.extra_cflags.append ("-fno-rtti")
@@ -762,19 +756,6 @@ def create_makefiles():
         installs= [("pykdeconfig.py", opt_pykdemoddir), ("contrib/kdepyuic", sipcfg.default_bin_dir)]
     ).generate()
 
-    if kde_version >= 0x030500:
-        f = open ("Makefile", "r")
-        buff = f.read ()
-        f.close ()
-        target  = os.path.join (opt_kdelibdir, "kde3", "libkonsolepart.so")
-        symlink = os.path.join (opt_kdelibdir, "libkonsolepart.so")
-        buff = buff.replace ("install:\n", "install:\n\tln -sf %s %s\n" % (target, symlink))
-        buff = buff.replace ("\nclean", "\tldconfig\n\nclean")
-        f = open ("Makefile.new", "w")
-        f.write (buff)
-        f.close ()
-        os.unlink ("Makefile")
-        os.rename ("Makefile.new", "Makefile")
 
 def fileOpts (fn):
     try:
